MiniButtonColors class

Helper container for button background / foreground / border colors.

Constructors

MiniButtonColors({required Color background, required Color foreground, required Color border, double borderWidth = 1})
const

Properties

background Color
final
border Color
final
borderWidth double
final
foreground Color
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited