hide static method
Hide the given loading overlay entry if it is still mounted.
Implementation
static void hide(OverlayEntry entry) {
if (entry.mounted) {
entry.remove();
}
}
Hide the given loading overlay entry if it is still mounted.
static void hide(OverlayEntry entry) {
if (entry.mounted) {
entry.remove();
}
}