components/nav/mini_tab_bar library

Classes

MiniTabBar
Tab bar that shows a list of equally divided navigation items at the top or bottom of the screen.
MiniTabItem
Configuration for a single tab item (label + optional icon).