BaseComponent class abstract
Base class for all components, exposing a shared themeOf helper.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- BaseComponent
- Implementers
- MiniAppBar
- MiniAvatar
- MiniBackButton
- MiniBadge
- MiniBanner
- MiniBottomSheet
- MiniButton
- MiniCard
- MiniCheckbox
- MiniDatePicker
- MiniDialog
- MiniDivider
- MiniEmpty
- MiniGrid
- MiniImage
- MiniListItem
- MiniLoadingOverlay
- MiniPageScaffold
- MiniRadio
- MiniResult
- MiniSectionHeader
- MiniSegmentedControl
- MiniSkeleton
- MiniSlider
- MiniSnackbar
- MiniStepper
- MiniSwitch
- MiniTabBar
- MiniTag
- MiniText
- MiniToast
Constructors
- BaseComponent({Key? key})
-
const
Properties
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
themeOf(
BuildContext context) → MiniTheme -
Get the current active MiniTheme from
context. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited