MiniThemeController class
Theme controller that stores the current MiniTheme and notifies listeners when it changes.
- Inheritance
-
- Object
- ChangeNotifier
- MiniThemeController
Constructors
-
MiniThemeController({MiniTheme? initialTheme, List<
MiniTheme> ? availableThemes})
Properties
-
availableThemes
→ List<
MiniTheme> -
All available themes that can be switched to.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → MiniTheme
-
Currently active theme.
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setTheme(
MiniTheme theme) → void - Set the theme instance directly and notify listeners if it changed.
-
setThemeByName(
String name) → void -
Find and switch theme by its
namefrom the available theme list. -
toString(
) → String -
A string representation of this object.
inherited
-
updateTokens(
{MiniSpacingTokens? spacing, MiniRadiusTokens? radius, MiniTypographyTokens? typography, MiniComponentSizeTokens? componentSizes}) → void - Update token groups (spacing / radius / typography / component sizes) based on the current theme.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited