setTheme method
Set the theme instance directly and notify listeners if it changed.
Implementation
void setTheme(MiniTheme theme) {
if (identical(theme, _theme)) {
return;
}
_theme = theme;
notifyListeners();
}
Set the theme instance directly and notify listeners if it changed.
void setTheme(MiniTheme theme) {
if (identical(theme, _theme)) {
return;
}
_theme = theme;
notifyListeners();
}