MiniComponentSizeTokens class

Constructors

MiniComponentSizeTokens({required EdgeInsets buttonPadding, required EdgeInsets inputPadding})
Component-level size tokens for controls such as buttons and inputs.
const

Properties

buttonPadding EdgeInsets
final
hashCode int
The hash code for this object.
no setteroverride
inputPadding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({EdgeInsets? buttonPadding, EdgeInsets? inputPadding}) MiniComponentSizeTokens
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override