MiniRadiusTokens class

Corner radius tokens used to unify corner styles across components.

Constructors

MiniRadiusTokens({required BorderRadius small, required BorderRadius medium, required BorderRadius large, required BorderRadius pill})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
large BorderRadius
final
medium BorderRadius
final
pill BorderRadius
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
small BorderRadius
final

Methods

copyWith({BorderRadius? small, BorderRadius? medium, BorderRadius? large, BorderRadius? pill}) MiniRadiusTokens
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited