MiniSpacingTokens class

Semantic spacing tokens from xs to xl, used to drive layout spacing.

Constructors

MiniSpacingTokens({required double xs, required double sm, required double md, required double lg, required double xl})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lg double
final
md double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm double
final
xl double
final
xs double
final

Methods

copyWith({double? xs, double? sm, double? md, double? lg, double? xl}) MiniSpacingTokens
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited