MiniTheme class

Aggregates color / spacing / radius / typography / component-size tokens into a complete theme.

Constructors

MiniTheme({required String name, required Brightness brightness, required MiniColorTokens colors, required MiniSpacingTokens spacing, required MiniRadiusTokens radius, required MiniTypographyTokens typography, required MiniComponentSizeTokens componentSizes})
const

Properties

brightness Brightness
final
colors MiniColorTokens
final
componentSizes MiniComponentSizeTokens
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
radius MiniRadiusTokens
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing MiniSpacingTokens
final
typography MiniTypographyTokens
final

Methods

copyWith({String? name, Brightness? brightness, MiniColorTokens? colors, MiniSpacingTokens? spacing, MiniRadiusTokens? radius, MiniTypographyTokens? typography, MiniComponentSizeTokens? componentSizes}) MiniTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(MiniTheme a, MiniTheme b, double t) MiniTheme