MiniThemes class
Built-in theme factory: bundles default spacing/radius/typography and several color palettes.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
Constants
- compactComponentSizes → const MiniComponentSizeTokens
- compactRadius → const MiniRadiusTokens
- compactSpacing → const MiniSpacingTokens
- compactTypography → const MiniTypographyTokens
- defaultComponentSizes → const MiniComponentSizeTokens
- defaultRadius → const MiniRadiusTokens
- defaultSpacing → const MiniSpacingTokens
- defaultTypography → const MiniTypographyTokens
- roundedComponentSizes → const MiniComponentSizeTokens
- roundedRadius → const MiniRadiusTokens
- roundedSpacing → const MiniSpacingTokens
- roundedTypography → const MiniTypographyTokens