MiniSpacingTokens class
Semantic spacing tokens from xs to xl, used to drive layout spacing.
Constructors
Properties
Methods
-
copyWith(
{double? xs, double? sm, double? md, double? lg, double? xl}) → MiniSpacingTokens -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited