MiniTypographyTokens class

Typography tokens used to unify text sizes and weights.

Constructors

MiniTypographyTokens({required TextStyle body, required TextStyle small, required TextStyle title, required TextStyle heading})
const

Properties

body TextStyle
final
hashCode int
The hash code for this object.
no setterinherited
heading TextStyle
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
small TextStyle
final
title TextStyle
final

Methods

copyWith({TextStyle? body, TextStyle? small, TextStyle? title, TextStyle? heading}) MiniTypographyTokens
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited